@@ -54,6 +54,8 @@ sPlotSpectra <- function(spectra, pca, pc = 1, tol = 0.05, ...) {
 ##  Matthew J. Keinsley
 ##  DePauw University, July 2011
 
+	msg <- "This function cannot be used with data from sparse pca"
+	if ("converted_from_arrayspc" %in% class(pca)) stop(msg)
 	.chkArgs(mode = 12L)
 	chkSpectra(spectra)
 	if (length(pc) != 1) stop("You must choose exactly 1 pc to plot.")
